<?php
/*
 百度云统一接入认证:
 认证字符串：非匿名请求中必须携带的认证信息。包含生成待签名串CanonicalRequest所必须的信息以及签名摘要signature。
 authStringPrefix：认证字符串的前缀部分。
 canonicalRequest：待签名串。携带经过规范化处理后的请求信息。
 signingKey：签名Key。百度云不直接使用SK对待签名串生成摘要。相反的，百度云首先使用SK和认证字符串前缀生成signingKey，然后用signingKey对待签名串生成摘要。
 signature：签名摘要。百度云使用signingKey对canonicalRequest使用HAMC算法计算签名。

*/
/*
生成UTC时间，默认是当前时间。比如说现在北京时间是2015/10/23 16:48:00.
那么对应的UTC时间就是当前时间减8小时，也就是2015/10/23 8:48:00
这里最终时间的格式是：2015-10-23T08:48:00Z
*/
date_default_timezone_set('UTC');
$utc_time_str = date("Y-m-d")."T".date("H:i:s")."Z";

$AK = '请修改为百度云的AK(Access Key)';
$SK = '请修改为百度云的SK(Secret Access Key)';

$host = 'yuqing.bce.baidu.com';  //此外为固定值，不需要改S
$path = '/v1/tasks'; //访问的接口，客户需按实际情况进行修改

$expirationPeriodInSeconds = "1800";

/*
 这里要生成signKey，生成signKey需要是将bce-auth-v1+AK+utc_time_str+过期时间拼接起来形成authStringPrefix.
 然后用签名中使用的HASH算法(HMAC SHA256)将刚才拼接的authStringPrefix和SK签一遍，打印出来signKey。
*/
$authStringPrefix = "bce-auth-v1"."/".$AK."/".$utc_time_str."/".$expirationPeriodInSeconds;
$SigningKey=hash_hmac('SHA256',$authStringPrefix,$SK);

/*
 对于GET请求，建议header里只需要加入host；如果是PUT请求，建议header里添加host和x-bce-date.如果你的header
 里还要加Content-lenth,Content-Type等，要将得到的字符串组按照字典序排序用换行符\n连接起来。
 CanoncialRequest由请求方法(GET，PUT或者POST), CanoncialURL,CanoncialHeaders组成。
*/
$CanonicalHeaders1 = "host;"."x-bce-date";
$CanonicalHeaders2 = "host:$host\n"."x-bce-date:".urlencode($utc_time_str);
$CanonicalString = "";//可以没有CanoncialString，也就是这一项为空
$CanonicalURI = $path; 
$CanonicalRequest = "POST\n".$CanonicalURI."\n".$CanonicalString."\n".$CanonicalHeaders2;  

/*使用 HMACSHA256 算法，SignKey，CanonicalRequest 生成最终签名*/
$Signature = hash_hmac('SHA256',$CanonicalRequest,$SigningKey);

/*
 生成认证字符串，认证字符串的格式为：
 bce-auth-v1/{AK}/{utc_time_str}/{expirationPeriodInSeconds}/{CanonicalHeaders1}/{signature}
*/
$Authorization = "bce-auth-v1/{$AK}/".$utc_time_str."/{$expirationPeriodInSeconds}/{$CanonicalHeaders1}/{$Signature}";
